Field

Struct Field 

pub struct Field<C: Context = DefaultContext> {
    pub status: FieldStatus,
    pub schema: Option<Schema<C>>,
}
A Field is a useful abstraction to record metadata that does not belong or would be unyieldy to place into the Schema and to account for cases in which the existence of a Field might be known, but nothing is known about its shape.

Fields

status: FieldStatus

The status holds information on the the field, like whether it might be null or missing altogether. Duplicate fields are also recorded.

schema: Option<Schema<C>>

The inner Schema is optional because we might have no information on the shape of the field (like for an empty array).

Implementations

Source

impl<C: Context> Field<C>

pub fn with_schema(schema: Schema<C>) -> Self

Returns a Field with the given Schema and default FieldStatus.