pub struct Field<C: Context = DefaultContext> {
pub status: FieldStatus,
pub schema: Option<Schema<C>>,
}Expand description
Fields
status: FieldStatusThe status holds information on the the field, like whether it might be null or missing altogether. Duplicate fields are also recorded.
schema: Option<Schema<C>>The inner Schema is optional because we might have no information on the shape of the field (like for an empty array).
Implementations
Sourceimpl<C: Context> Field<C>
impl<C: Context> Field<C>
Sourcepub fn with_schema(schema: Schema<C>) -> Self
pub fn with_schema(schema: Schema<C>) -> Self
Returns a Field with the given Schema and default FieldStatus.